@@ -170,7 +170,7 @@ inserted."
 
 ;;Regexps for identifying source line parts for font-lock.
 (defvar apt-sources-font-lock-deb-regexp "\\(deb\\|deb-src\\)"
-  "A regexp that matches 'deb' or 'deb-src' at the begining of line.")
+  "A regexp that matches `deb' or `deb-src' at the begining of line.")
 
 (defvar apt-sources-font-lock-uri-regexp
   "\\([^ ]+\\)"
@@ -300,16 +300,16 @@ of the format."
 					 ("frozen" 3)
 					 ("stable" 4)
 					 ("sid" 5)
-					 ("squeeze" 6)
-					 ("wheezy" 7)
-					 ("jessie" 8)) nil t))
+					 ("bullseye" 6)
+					 ("bookworm" 7)
+					 ("trixie" 8)) nil t))
 	(components (completing-read "Components: " ;list of componenst used by APT.
 				     '(("main")
 				       ("main contrib")
-				       ("main contrib non-free")
+				       ("main contrib non-free non-free-firmware")
 				       ("contrib")
-				       ("contrib non-free")
-				       ("non-free"))))
+				       ("contrib non-free non-free-firmware")
+				       ("non-free non-free-firmware"))))
 	(blank-line (if apt-sources-around-lines "\n" "")))
     (save-excursion
       (beginning-of-line)
@@ -336,7 +336,7 @@ This modifies the state of variable `apt-sources-around-lines'."
 (defun apt-sources-insert-local-vars ()
   "Insert the current values of buffer local variables."
   (interactive)
-  (end-of-buffer)
+  (goto-char (point-max))
   (and (not (bolp))
        (insert "\n"))   ;insert a newline if the file doesn't end in a blank line.
   (insert "\n"
@@ -375,7 +375,7 @@ ARG is the prefix argument."
 
 (defun apt-sources-change-source-type ()
   "Change the type of the source line.
-TYPE is either 'd' or 's' to change the type to 'deb' or 'deb-src'.
+TYPE is either `d' or `s' to change the type to `deb' or `deb-src'.
 
 This function will rise an error if we are not in a source line."
   (interactive)
@@ -412,7 +412,7 @@ This function will rise an error if we are not in a source line."
 (defun apt-sources-change-uri-address (uri-address)
   "Change the URI address of the source line.
 String URI-ADDRESS is the address (without the type of address,
-ex: 'http://').
+ex: `http://').
 
 This function will rise an error if we are not in a source line."
   (interactive "sURI address: ")
@@ -435,9 +435,9 @@ This function will rise an error if we are not in a source line."
 					      ("frozen" 3)
 					      ("stable" 4)
 					      ("sid" 5)
-					      ("squeeze" 6)
-					      ("wheezy" 7)
-					      ("jessie" 8)) nil t)))
+					      ("bullseye" 6)
+					      ("bookworm" 7)
+					      ("trixie" 8)) nil t)))
 	 (save-excursion
 	   (beginning-of-line)
 	   (delete-region (re-search-forward ":/*[^ ]*." (line-end-position) t 1)
@@ -453,10 +453,10 @@ This function will rise an error if we are not in a source line."
        (let ((components (completing-read "Components: " ;list of componenst used by APT.
 					  '(("main")
 					    ("main contrib")
-					    ("main contrib non-free")
+					    ("main contrib non-free non-free-firmware")
 					    ("contrib")
-					    ("contrib non-free")
-					    ("non-free")))))
+					    ("contrib non-free non-free-firmware")
+					    ("non-free non-free-firmware")))))
 	 (save-excursion
 	   (beginning-of-line)
 	   (delete-region (re-search-forward ":/*[^ ]* [^ ]*." (line-end-position) t 1)
@@ -468,7 +468,7 @@ This function will rise an error if we are not in a source line."
 	   (insert components)))))
 
 (defun apt-sources-deb-or-src-replicate ()
-  "Copy the source line and change the 'deb' to 'deb-src' or viceversa.
+  "Copy the source line and change the `deb' to `deb-src' or vice versa.
 
 This function will rise an error if we are not on a source line."
   (interactive)
