@@ -23,7 +23,7 @@
 ;;; Commentary:
 ;;
 ;; Package to interface Emacs with APT.  Start things off using e.g.:
-;; M-x apt-utils-show-package RET emacs21 RET
+;; M-x apt-utils-show-package RET emacs RET
 ;;
 ;; Other packages (dependencies, conflicts etc.) can be navigated
 ;; using apt-utils-{next,previous}-package,
@@ -316,21 +316,23 @@ These are stored in a hash table.  See also
   "Use font-lock-face if `add-text-properties' supports it.
 Otherwise, just use face.")
 
-(cond
- ;; Emacs 21
- ((fboundp 'replace-regexp-in-string)
-  (defalias 'apt-utils-replace-regexp-in-string 'replace-regexp-in-string))
- ;; Emacs 20
- ((and (require 'dired)
-       (fboundp 'dired-replace-in-string))
-  (defalias 'apt-utils-replace-regexp-in-string 'dired-replace-in-string))
- ;; XEmacs
- ((fboundp 'replace-in-string)
-  (defun apt-utils-replace-regexp-in-string (regexp rep string)
-    (replace-in-string string regexp rep)))
- ;; Bail out
- (t
-  (error "No replace in string function found")))
+(defalias 'apt-utils-replace-regexp-in-string
+  (cond
+   ;; Emacs 21
+   ((fboundp 'replace-regexp-in-string)
+    'replace-regexp-in-string)
+   ;; Emacs 20
+   ((and (require 'dired)
+         (fboundp 'dired-replace-in-string))
+    'dired-replace-in-string)
+   ;; XEmacs
+   ((fboundp 'replace-in-string)
+    (lambda (regexp rep string)
+      (replace-in-string string regexp rep)))
+   ;; Bail out
+   (t
+    (lambda (&rest rest)
+      (error "No replace in string function found")))))
 
 ;; Commands and functions
 
@@ -595,7 +597,9 @@ search is specified by PROMPT."
       (apt-utils-sort-result)
       (set-buffer-modified-p nil)
       (setq buffer-read-only t)
-      (display-buffer (current-buffer)))))
+      (if apt-utils-use-current-window
+          (switch-to-buffer (current-buffer))
+        (select-window (display-buffer (current-buffer)))))))
 
 (defun apt-utils-search-grep-dctrl ()
   "Search Debian packages for regular expression using grep-dctrl."
@@ -1051,7 +1055,7 @@ a choice."
         (let ((process-environment (append '("COLUMNS=200") (copy-alist process-environment))))
           (call-process apt-utils-dpkg-program nil t nil "-l" package))
         (when (re-search-backward
-               (format "^\\([a-z ][a-z ][a-z ]\\)\\s-+%s\\s-+\\(\\S-+\\)"
+               (format "^\\([a-z ][a-z ][a-z ]\\)\\s-+%s\\(?:\\:\\S-+\\)?\\s-+\\(\\S-+\\)"
                        (regexp-quote package)) nil t)
           (progn
             (setq desired (aref (match-string 1) 0)
@@ -2032,7 +2036,7 @@ The tokens that can be replaced are:
 
 Start things off with, for example:
 
-    M-x apt-utils-show-package RET emacs21 RET
+    M-x apt-utils-show-package RET emacs RET
 
 Other packages (dependencies, conflicts etc.) can be navigated
 using:
